mapbox_maps_flutter_platform_interface library
Classes
- AmbientLight
- An indirect light affecting all objects in the map adding a constant amount of light on them. It has no explicit direction and cannot cast shadows.
- AnnotationInteractionContext
- AnnotationManagerPlatformInterface
- Abstract interface for the annotation manager factory.
- AttributionSettings
- Shows the attribution icon on the map.
- AttributionSettingsPlatformInterface
- Interface for attribution ornament settings.
- BaseAnnotationManagerPlatformInterface
- Base interface for all annotation manager interfaces.
- CameraBounds
-
Holds information about
camera bounds. - CameraBoundsOptions
-
Holds options to be used for setting
camera bounds. - CameraChangedEventData
-
Data for the
cameraChangedevent. - CameraOptions
- Various options for describing the viewpoint of a camera. All fields are optional.
- CameraState
- Describes the viewpoint of a camera.
- CameraViewportState
- Manually sets camera to specified properties.
- Cancelable
- A class representing a cancelable operation or task.
- CanonicalTileID
- Represents a tile coordinate.
- CircleAnnotation
- CircleAnnotationInteractionContext
- CircleAnnotationManagerPlatformInterface
- Abstract interface for managing circle annotations.
- CircleAnnotationOptions
- CompassSettings
- Shows the compass on the map.
- CompassSettingsPlatformInterface
- Interface for compass ornament settings.
- CoordinateBounds
- Coordinate bounds representation.
- CoordinateBoundsZoom
- A coordinate bounds and zoom.
- CumulativeRenderingStatistics
- DefaultLocationPuck2D
- Marker subclass of LocationPuck2D that signals the platform implementation should fall back to the default 2D puck imagery (top / bearing / shadow) for any sprite slot the caller leaves unset.
- DefaultViewportTransition
- A ViewportTransition that provides a default animation for viewport changes.
- DirectionalLight
- A light that has a direction and is located at infinite, so its rays are parallel. Simulates the sun light and it can cast shadows
- Disposable
- Anything that holds resources requiring an explicit cleanup signal.
- DisposeBag
- A collection of Disposables disposed together.
- DurationStatistics
- EasingViewportTransition
- A ViewportTransition that animates viewport changes using an easing curve.
- EventTimeInterval
- The time interval of an event.
- FeatureExtensionValue
- A value or a collection of a feature extension.
- FeaturesetDescriptor
- A featureset descriptor.
- FeaturesetFeature
- A basic feature of a featureset.
- FeaturesetFeatureId
- An identifier for a feature in a featureset.
- FeatureState
- Wraps a FeatureState map
- FlatLight
- A global directional light source which is only applied on 3D layers and hillshade layers. Using this type disables other light sources.
- FlyViewportTransition
- A ViewportTransition that performs a fly animation over a specified duration.
- FollowPuckViewportState
- A ViewportState that configures the camera to follow the user's location indicator (puck).
- FollowPuckViewportStateBearing
- Specifies the different ways that FollowPuckViewportState can obtain values to use when setting the camera's bearing.
- FollowPuckViewportStateBearingConstant
- Sets the camera's bearing to a constant value.
- FollowPuckViewportStateBearingCourse
- Sets the camera's bearing based on the device's current course (direction of movement).
- FollowPuckViewportStateBearingHeading
- Sets the camera's bearing based on the device's current heading.
- GesturesSettings
- Gesture configuration allows to control the user touch interaction.
- GesturesSettingsPlatformInterface
- Interface for gesture configuration and observability.
- GlyphsRasterizationOptions
- Describes the glyphs rasterization option values.
- GroupPerformanceStatistics
- IdleViewportState
- Idle viewport represents the state when user freely drags the map.
- ImageContent
- Describes the image content, e.g. where text can be fit into an image.
- ImageStretches
- Describes the image stretch areas.
- ImmediateViewportTransition
- A ViewportTransition that applies the new viewport state instantly, with no animation.
- ImportPosition
-
Specifies the position at which an import will be added when using
Style.addImport. - IndoorSelectorSettings
- Settings for the indoor floor selector.
- IndoorSelectorSettingsPlatformInterface
- Interface for indoor floor selector settings.
- Interaction
- Base class for interactions that can be added to the map.
- LayerPosition
- Specifies position of a layer that is added via addStyleLayer method.
- LocationComponentSettings
- Shows a location puck on the map.
- LocationPuck
- Defines what the customised look of the location puck. Note that direct changes to the puck variables won't have any effect, a new puck needs to be set every time.
- LocationPuck2D
- 2D location puck configuration.
- LocationPuck3D
- 3D location puck configuration.
- LocationSettingsPlatformInterface
- Abstract interface for managing the user location indicator.
- LogConfigurationPlatformInterface
- Global log-backend configuration for Mapbox SDKs.
- LogoSettings
- Shows the Mapbox logo on the map.
- LogoSettingsPlatformInterface
- Interface for logo ornament settings.
- LogWriterBackend
- An interface for implementing log writing backends — e.g. for using platform-specific log backends or logging to a notification service.
- MapAnimationOptions
- Options for camera animations.
- MapboxHttpServicePlatformInterface
- Abstract interface for configuring HTTP requests made by the Mapbox SDK.
- MapboxMapInterface
- Marker interface for a MapboxMap instance.
- MapboxMapPlatformInterface
- Abstract per-instance controller for a Mapbox map.
- MapboxMapsFlutterPlatform
- MapboxMapsOptionsPlatformInterface
- Abstract interface for managing global Mapbox Maps configuration options.
- MapboxOptionsPlatformInterface
- Abstract interface for managing the Mapbox access token.
- MapContentGestureContext
- A structure that defines additional information about map content gesture.
- MapEvent
- Base sealed class for all map events.
- MapIdleEventData
-
Data for the
mapIdleevent. - MapLoadedEventData
-
Data for the
mapLoadedevent. - MapLoadingErrorEventData
-
Data for the
mapLoadingErrorevent. - MapOptions
- Describes the map option values.
- MapRecorderPlatformInterface
- MapRecorder provides functions to record and replay API calls of a map instance.
- MapSnapshotOptions
-
Set of options for taking map snapshot with
map snapshotter. - MapWidgetDebugOptions
- Options for enabling debugging features in a map.
- MbxEdgeInsets
- The distance on each side between rectangles, when one is contained into other.
- MbxImage
- Image type.
- MercatorCoordinate
- Describes a point on the map in Mercator projection.
- OfflineManagerPlatformInterface
- Abstract interface for managing offline style packages.
- OfflineSwitchPlatformInterface
- Abstract interface for controlling the Mapbox network stack connectivity.
- OverviewViewportState
- A viewport state that configures the camera to display an overview of a specified geometry.
- PerformanceStatistics
- The performance statistics collected at the end of the sampling duration.
- PerformanceStatisticsListener
-
Performance-statistics callback — users subclass and pass an instance
to
MapboxMap.startPerformanceStatisticsCollectionto receive sampled PerformanceStatistics snapshots. - PerformanceStatisticsOptions
- Options for the following statistics collection behaviors:
- PerFrameRenderingStatistics
- PointAnnotation
- PointAnnotationInteractionContext
- PointAnnotationManagerPlatformInterface
- Abstract interface for managing point annotations.
- PointAnnotationOptions
- PolygonAnnotation
- PolygonAnnotationInteractionContext
- PolygonAnnotationManagerPlatformInterface
- Abstract interface for managing polygon annotations.
- PolygonAnnotationOptions
- PolylineAnnotation
- PolylineAnnotationInteractionContext
- PolylineAnnotationManagerPlatformInterface
- Abstract interface for managing polyline annotations.
- PolylineAnnotationOptions
- ProjectedMeters
- ProjectedMeters is a coordinate in a specific Spherical Mercator projection.
- ProjectionPlatformInterface
- Collection of Spherical Mercator projection methods.
- QueriedFeature
- Represents query result that is returned in QueryFeaturesCallback.
- QueriedRenderedFeature
- Represents query result that is returned in QueryRenderedFeaturesCallback.
- QueriedSourceFeature
- Represents query result that is returned in QuerySourceFeaturesCallback.
- RenderedQueryGeometry
- Geometry for querying rendered features.
- RenderedQueryOptions
- Options for querying rendered features.
- RenderFrameFinishedEventData
-
Data for the
renderFrameFinishedevent. - RenderFrameStartedEventData
-
Data for the
renderFrameStartedevent. - ResourceEventData
-
Data for the
resourceRequestevent. - ResourceRequest
- A resource request.
- ResourceResponse
- A resource response.
- ResponseError
- An error in a resource response.
- ScaleBarSettings
- Shows the scale bar on the map.
- ScaleBarSettingsPlatformInterface
- Interface for scale bar ornament settings.
- ScreenBox
- A rectangular area as measured in the map's coordinate system.
- ScreenCoordinate
-
Describes the coordinate on the screen, measured from top to bottom and from left to right.
Note: the
mapuses screen coordinate units measured inlogical pixels. -
SettingsPlatformInterface<
T> -
Generic interface for reading and updating a map settings object of type
T. - Size
- Size type.
- SnapshotterPlatformInterface
- Abstract interface for capturing styled map snapshots.
- SourceAddedEventData
-
Data for the
sourceAddedevent. - SourceDataLoadedEventData
-
Data for the
sourceDataLoadedevent. - SourceQueryOptions
- Options for querying source features.
- SourceRemovedEventData
-
Data for the
sourceRemovedevent. - StyleDataLoadedEventData
-
Data for the
styleDataLoadedevent. - StyleDefaultViewportState
- Sets camera to the default camera options defined in the current style.
- StyleImageMissingEventData
-
Data for the
styleImageMissingevent. - StyleImageUnusedEventData
-
Data for the
styleImageUnusedevent. - StyleLoadedEventData
-
Data for the
styleLoadedevent. - StyleObjectInfo
- The information about style object (source or layer).
- StylePack
-
The
style packrepresents a stored style package. - StylePackLoadOptions
- Describes the style package load option values.
- StylePackLoadProgress
-
A
style pack loadprogress includes information about the number of resources that have completed downloading and the total number of resources that are required. - StylePlatformInterface
- Abstract interface for managing the map's style.
- StyleProjection
- The style projection.
- StylePropertyValue
- Holds a style property value with meta data.
- TileCacheBudgetInMegabytes
- Map memory budget in megabytes.
- TileCacheBudgetInTiles
- Map memory budget in tiles.
- TileCoverOptions
- Various options needed for tile cover.
- TileID
- Identifies a tile by its z/x/y coordinates.
- TileRegion
- TileRegion represents an identifiable geographic tile region with metadata.
- TileRegionEstimateOptions
- Holds options for the tile region estimation operation.
- TileRegionEstimateProgress
- A tile region's estimate progress includes counts of the number of resources that have been estimated and the total number of resources, as well as a partial result.
- TileRegionEstimateResult
- The result of tile region estimation.
- TileRegionLoadOptions
- Describes the tile region load option values.
- TileRegionLoadProgress
- A tile region's load progress includes counts of the number of resources that have completed downloading and the total number of resources that are required.
- TilesetDescriptorOptions
- Describes the tileset descriptor option values.
- TileStorePlatformInterface
- Abstract interface for managing tile store downloads.
- TransitionOptions
- Defines global transition options that are used when properties are changed without specific transition options.
-
TypedFeaturesetFeature<
T extends FeaturesetDescriptor> - A FeaturesetFeature with a typed FeaturesetDescriptor. This is used to provide typed access to the specific properties and state of a feature with a known type such as StandardPOIs or StandardBuildings.
-
TypedInteraction<
T extends TypedFeaturesetFeature< FeaturesetDescriptor> > - An Interaction with an action that has a typed FeaturesetFeature as input.
- ViewportPlatformInterface
- Abstract interface for performing viewport transitions.
- ViewportState
- A base class representing different ways to position the camera on a map.
- ViewportTransition
- A base class for defining custom viewport transitions.
Enums
- Anchor
- Whether extruded geometries are lit relative to the map or viewport.
- AndroidPlatformViewHostingMode
- A mode for platform MapView to be hosted in Flutter on Android.
- BackgroundPitchAlignment
- Orientation of background layer.
- CircleElevationReference
- Selects the base of the circle-elevation-reference. Default value: "none".
- CirclePitchAlignment
- Orientation of circle when map is pitched. Default value: "viewport".
- CirclePitchScale
- Controls the scaling behavior of the circle when the map is pitched. Default value: "map".
- CircleTranslateAnchor
-
Controls the frame of reference for
circle-translate. Default value: "map". - ConstrainMode
- Describes whether to constrain the map in both axes or only vertically e.g. while panning.
- ContextMode
- Describes the map context mode. We can make some optimizations if we know that the drawing context is not shared with other code.
- DataSourceType
- Describes the data source type for a resource request.
- DistanceUnits
- Supported distance unit types. Default value: "metric".
- Encoding
- Encoding of raster-DEM tiles.
- FillElevationReference
- Selects the base of fill-elevation-reference. Default value: "none".
- FillExtrusionBaseAlignment
- Controls the behavior of fill extrusion base over terrain
- FillExtrusionHeightAlignment
- Controls the behavior of fill extrusion height over terrain
- FillExtrusionTranslateAnchor
-
Controls the frame of reference for
fill-extrusion-translate. - FillTranslateAnchor
-
Controls the frame of reference for
fill-translate. Default value: "map". - GestureState
- Enumeration of gesture states.
- GlyphsRasterizationMode
- Describes glyphs rasterization modes.
- HillshadeIlluminationAnchor
- Direction of light source when map is rotated.
- IconAnchor
- Part of the icon placed closest to the anchor. Default value: "center".
- IconPitchAlignment
- Orientation of icon when map is pitched. Default value: "auto".
- IconRotationAlignment
-
In combination with
symbol-placement, determines the rotation behavior of icons. Default value: "auto". - IconTextFit
- Scales the icon to fit around the associated text. Default value: "none".
- IconTranslateAnchor
-
Controls the frame of reference for
icon-translate. Default value: "map". - LineCap
- The display of line endings. Default value: "butt".
- LineElevationReference
- Selects the base of line-elevation-reference. Default value: "none".
- LineJoin
- The display of lines when joining. Default value: "miter".
- LineTranslateAnchor
-
Controls the frame of reference for
line-translate. Default value: "map". - LineWidthUnit
- Selects the unit of line-width. The same unit is automatically used for line-blur and line-offset. Note: This is an experimental property, and is subject to change in future versions. Default value: "pixels".
- LoggingLevel
- States level of a log message.
- MapLoadErrorType
- Describes what resource could not be loaded.
- MapWidgetDebugOptionsData
- Raw Pigeon enum underlying the MapWidgetDebugOptions typed wrapper. Exposed publicly (rather than with an underscore prefix) because the wrapper now lives in the platform-interface package and needs to round- trip values across package boundaries for mobile's Pigeon channels.
- ModelElevationReference
- Selects the base of the model. Default value: "ground".
- ModelScaleMode
- Defines scaling mode. Only applies to location-indicator type layers. Default value: "map".
- ModelType
- Defines rendering behavior of model in respect to other 3D scene objects.
- NetworkRestriction
- Classify network types based on cost.
- NorthOrientation
- Describes the map orientation.
- OcclusionOpacityMode
- Occlusion opacity mode. Default value: "anchor".
- OrnamentPosition
- Defines the position of an ornament (logo, compass, scale bar, attribution) on the map.
- PerformanceSamplerOptions
- Samplers which can be optionally enabled to collect performance statistics.
- PuckBearing
- The enum controls how the puck is oriented. Default value: "heading".
- RasterResampling
- The resampling/interpolation method to use for overscaling, also known as texture magnification filter.
- RenderMode
- Describes whether a map or frame has been fully rendered.
- RequestLoadingMethodType
- The method used to make a resource request.
- RequestPriority
- The priority of a request.
- RequestType
- The type of a requested resource.
- ResponseErrorReason
- Describes the reason for an offline request response error. Also generated in native (Swift/Kotlin) pigeon output for MapInterfaces.
- ResponseSourceType
- The source of a response.
- Scheme
- Influences the y direction of the tile coordinates. The global-mercator (aka Spherical Mercator) profile is assumed.
- ScrollMode
- Configures the directions in which the map is allowed to move during a scroll gesture. Default value: "horizontal-and-vertical".
- SkyType
- The type of the sky.
- SourceDataType
- Defines what kind of source data was loaded.
- StyleDataType
- Defines what kind of style data was loaded.
- StyleProjectionName
- The style projection name.
- StylePropertyValueKind
- Describes the kind of a style property value.
- SymbolElevationReference
- Selects the base of symbol-elevation. Default value: "ground".
- SymbolPlacement
- Label placement relative to its geometry. Default value: "point".
- SymbolZOrder
-
Determines whether overlapping symbols in the same layer are rendered in the order that they appear in the data source or by their y-position relative to the viewport. To control the order and prioritization of symbols otherwise, use
symbol-sort-key. Default value: "auto". - TextAnchor
- Part of the text placed closest to the anchor. Default value: "center".
- TextJustify
- Text justification options. Default value: "center".
- TextPitchAlignment
- Orientation of text when map is pitched. Default value: "auto".
- TextRotationAlignment
-
In combination with
symbol-placement, determines the rotation behavior of the individual glyphs forming the text. Default value: "auto". - TextTransform
-
Specifies how to capitalize text, similar to the CSS
text-transformproperty. Default value: "none". - TextTranslateAnchor
-
Controls the frame of reference for
text-translate. Default value: "map". - TextVariableAnchor
-
To increase the chance of placing high-priority labels on the map, you can provide an array of
text-anchorlocations: the renderer will attempt to place the label at each location, in order, before moving onto the next label. Usetext-justify: autoto choose justification based on anchor position. To apply an offset, use thetext-radial-offsetor the two-dimensionaltext-offset. - TextWritingMode
-
The property allows control over a symbol's orientation. Note that the property values act as a hint, so that a symbol whose language doesn't support the provided orientation will be laid out in its natural orientation. Example: English point symbol will be rendered horizontally even if array value contains single 'vertical' enum value. For symbol with point placement, the order of elements in an array define priority order for the placement of an orientation variant. For symbol with line placement, the default text writing mode is either
'horizontal', 'vertical'or'vertical', 'horizontal', the order doesn't affect the placement. - TileDataDomain
- Describes the tiles data domain.
- TileStoreUsageMode
- Describes tile store usage modes.
- Type
- Type information of the variant's content
- ViewportMode
- Satisfies embedding platforms that requires the viewport coordinate systems to be set according to its standards.
Extension Types
- InteractionType
- The kind of gesture an Interaction listens for.
Extensions
Typedefs
-
MapboxMapCreatedCallback<
T extends MapboxMapInterface> = void Function(T mapboxMap) - Callback signature invoked when a map instance is ready.
- OnCameraChangeListener = void Function(CameraChangedEventData cameraChangedEventData)
- Invoked whenever the camera position changes.
-
OnInteraction<
T extends FeaturesetFeature> = void Function(T? feature, MapContentGestureContext context) - Interaction callback for any feature type.
- OnInteractionContext = void Function(MapContentGestureContext context)
- Interaction callback that just returns the MapContentGestureContext.
-
OnInteractionFeatureContext<
T extends FeaturesetFeature> = void Function(T feature, MapContentGestureContext context) - Interaction callback for a specific featureset which returns a non-optional FeaturesetFeature.
- OnMapIdleListener = void Function(MapIdleEventData mapIdleEventData)
- Invoked whenever the map has entered the idle state.
- OnMapLoadedListener = void Function(MapLoadedEventData mapLoadedEventData)
- Invoked when map loading finishes.
- OnMapLoadErrorListener = void Function(MapLoadingErrorEventData mapLoadingErrorEventData)
- Invoked whenever the map load errors out.
- OnMapLongTapListener = void Function(MapContentGestureContext context)
- Gesture listener called on map long tap.
- OnMapScrollListener = void Function(MapContentGestureContext context)
- Gesture listener called on map scroll.
- OnMapTapListener = void Function(MapContentGestureContext context)
- Gesture listener called on map tap.
- OnMapZoomListener = void Function(MapContentGestureContext context)
- Gesture listener called on map zoom.
- OnRenderFrameFinishedListener = void Function(RenderFrameFinishedEventData renderFrameFinishedEventData)
- Invoked whenever the map finished rendering a frame.
- OnRenderFrameStartedListener = void Function(RenderFrameStartedEventData renderFrameStartedEventData)
- Invoked whenever the map started rendering a frame.
- OnResourceRequestListener = void Function(ResourceEventData resourceEventData)
- Invoked when the map makes a resource request.
- OnSourceAddedListener = void Function(SourceAddedEventData sourceAddedEventData)
- Invoked whenever a source is added.
- OnSourceDataLoadedListener = void Function(SourceDataLoadedEventData sourceDataLoadedEventData)
- Invoked when the requested source data has been loaded.
- OnSourceRemovedListener = void Function(SourceRemovedEventData sourceRemovedEventData)
- Invoked whenever a source is removed.
- OnStyleDataLoadedListener = void Function(StyleDataLoadedEventData styleDataLoadedEventData)
- Invoked when the requested style data has been loaded.
- OnStyleImageMissingListener = void Function(StyleImageMissingEventData styleImageMissingEventData)
- Invoked when the style has a missing image.
- OnStyleImageUnusedListener = void Function(StyleImageUnusedEventData styleImageUnusedEventData)
- Invoked when an image added to the style is no longer needed.
- OnStyleLoadedListener = void Function(StyleLoadedEventData styleLoadedEventData)
- Invoked when the style is fully loaded.
- OnStylePackLoadProgressListener = void Function(StylePackLoadProgress progress)
- StylePack load progress callback.
- OnTileRegionEstimateProgressListener = void Function(TileRegionEstimateProgress progress)
- TileRegion estimate progress callback.
- OnTileRegionLoadProgressListener = void Function(TileRegionLoadProgress progress)
- TileRegion load progress callback.
-
PlatformMapCreatedCallback
= MapboxMapCreatedCallback<
MapboxMapPlatformInterface>